@@ -2,7 +2,10 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, Any
 
-from narwhals._pandas_like.utils import select_columns_by_name
+from narwhals._pandas_like.utils import (
+    make_group_by_kwargs as pd_make_group_by_kwargs,
+    select_columns_by_name,
+)
 from narwhals._utils import Implementation, Version, isinstance_or_issubclass
 from narwhals.dependencies import get_pyarrow
 
@@ -19,20 +22,10 @@ if TYPE_CHECKING:
 else:
     try:
         import dask.dataframe.dask_expr as dx
-    except ModuleNotFoundError:  # pragma: no cover
+    except ModuleNotFoundError:
         import dask_expr as dx
 
 
-def maybe_evaluate_expr(df: DaskLazyFrame, obj: DaskExpr | object) -> dx.Series | object:
-    from narwhals._dask.expr import DaskExpr
-
-    if isinstance(obj, DaskExpr):
-        results = obj._call(df)
-        assert len(results) == 1  # debug assertion  # noqa: S101
-        return results[0]
-    return obj
-
-
 def evaluate_exprs(df: DaskLazyFrame, /, *exprs: DaskExpr) -> list[tuple[str, dx.Series]]:
     native_results: list[tuple[str, dx.Series]] = []
     for expr in exprs:
@@ -137,3 +130,9 @@ def narwhals_to_native_dtype(dtype: IntoDType, version: Version) -> Any:
         raise NotImplementedError(msg)
     msg = f"Unknown dtype: {dtype}"  # pragma: no cover
     raise AssertionError(msg)
+
+
+def make_group_by_kwargs(*, drop_null_keys: bool) -> dict[str, bool]:
+    kwargs = pd_make_group_by_kwargs(drop_null_keys=drop_null_keys)
+    kwargs.pop("as_index")  # not supported in dask
+    return kwargs
