@@ -1,10 +1,12 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Iterator, Sequence, cast
+from typing import TYPE_CHECKING, cast
 
 from narwhals._utils import is_sequence_of
 
 if TYPE_CHECKING:
+    from collections.abc import Iterator, Sequence
+
     from polars.dataframe.group_by import GroupBy as NativeGroupBy
     from polars.lazyframe.group_by import LazyGroupBy as NativeLazyGroupBy
 
@@ -15,8 +17,6 @@ if TYPE_CHECKING:
 class PolarsGroupBy:
     _compliant_frame: PolarsDataFrame
     _grouped: NativeGroupBy
-    _drop_null_keys: bool
-    _output_names: Sequence[str]
 
     @property
     def compliant(self) -> PolarsDataFrame:
@@ -50,8 +50,6 @@ class PolarsGroupBy:
 class PolarsLazyGroupBy:
     _compliant_frame: PolarsLazyFrame
     _grouped: NativeLazyGroupBy
-    _drop_null_keys: bool
-    _output_names: Sequence[str]
 
     @property
     def compliant(self) -> PolarsLazyFrame:
