@@ -6,13 +6,9 @@ import narwhals as nw
 from tests.utils import DUCKDB_VERSION, Constructor, assert_equal_data
 
 
-def test_over_pushdown(constructor: Constructor, request: pytest.FixtureRequest) -> None:
+def test_over_pushdown(constructor: Constructor) -> None:
     if "duckdb" in str(constructor) and DUCKDB_VERSION < (1, 3):
         pytest.skip()
-    if any(x in str(constructor) for x in ("pyarrow", "pandas", "dask", "cudf", "modin")):
-        # non-trivial aggregation
-        request.applymarker(pytest.mark.xfail)
-
     data = {"a": [1, 2, -4, 5, 6, -1], "b": [1, 1, 1, 2, 2, 2], "i": list(range(6))}
     df = nw.from_native(constructor(data))
     result = df.select(
