@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import os
 from datetime import datetime
+from pathlib import Path
 from typing import TYPE_CHECKING
 from unittest import mock
 
@@ -13,6 +14,8 @@ from tests.utils import DASK_VERSION, PANDAS_VERSION, assert_equal_data
 if TYPE_CHECKING:
     from narwhals.typing import IntoFrame
 
+PATH = Path(__file__).parent / "data/lineitem.csv"
+
 
 @pytest.mark.parametrize("library", ["pandas", "polars", "pyarrow", "dask"])
 @pytest.mark.filterwarnings("ignore:.*Passing a BlockManager.*:DeprecationWarning")
@@ -24,25 +27,23 @@ def test_q1(library: str) -> None:
     elif library == "pandas":
         import pandas as pd
 
-        df_raw: IntoFrame = pd.read_csv("tests/data/lineitem.csv")
+        df_raw: IntoFrame = pd.read_csv(PATH)
     elif library == "polars":
         pytest.importorskip("polars")
         import polars as pl
 
-        df_raw = pl.scan_csv("tests/data/lineitem.csv")
+        df_raw = pl.scan_csv(PATH)
     elif library == "dask":
         pytest.importorskip("dask")
         import dask.dataframe as dd
         import pandas as pd
 
-        df_raw = dd.from_pandas(
-            pd.read_csv("tests/data/lineitem.csv", dtype_backend="pyarrow")
-        )
+        df_raw = dd.from_pandas(pd.read_csv(PATH))
     else:
         pytest.importorskip("pyarrow.csv")
         import pyarrow.csv as pa_csv
 
-        df_raw = pa_csv.read_csv("tests/data/lineitem.csv")
+        df_raw = pa_csv.read_csv(PATH)
     var_1 = datetime(1998, 9, 2)
     df = nw.from_native(df_raw).lazy()
     schema = df.collect_schema()
@@ -109,12 +110,12 @@ def test_q1_w_generic_funcs(library: str) -> None:
     elif library == "pandas":
         import pandas as pd
 
-        df_raw: pd.DataFrame | pl.DataFrame = pd.read_csv("tests/data/lineitem.csv")
+        df_raw: pd.DataFrame | pl.DataFrame = pd.read_csv(PATH)
     else:
         pytest.importorskip("polars")
         import polars as pl
 
-        df_raw = pl.read_csv("tests/data/lineitem.csv")
+        df_raw = pl.read_csv(PATH)
     var_1 = datetime(1998, 9, 2)
     df = nw.from_native(df_raw, eager_only=True)
     df = df.with_columns(nw.col("l_shipdate").str.to_datetime())
@@ -174,7 +175,7 @@ def test_q1_w_pandas_agg_generic_path() -> None:
     pytest.importorskip("pandas")
     import pandas as pd
 
-    df_raw = pd.read_csv("tests/data/lineitem.csv")
+    df_raw = pd.read_csv(PATH)
     df_raw["l_shipdate"] = pd.to_datetime(df_raw["l_shipdate"])
     var_1 = datetime(1998, 9, 2)
     df = nw.from_native(df_raw).lazy()
